@@ -30,5 +30,5 @@ namespace ROPTLIB{
 		/*Print this point on tangent space of oblique as a matrix*/
 		virtual void Print(const char *name = "", bool isonlymain = true) const;
 	};
-}; /*end of ROPTLIB namespace*/
+} /*end of ROPTLIB namespace*/
 #endif // end of OBLIQUEVECTOR_H
