@@ -119,7 +119,7 @@ namespace ROPTLIB{
 		double one = 1, zero = 0;
 		integer inc = 1, N = ell;
 		// Hxpy <- M(: start : start + length - 1) * xpyTV, details: http://www.netlib.org/lapack/explore-html/dc/da8/dgemv_8f.html
-		dgemv_(transn, &N, &length, &one, const_cast<double *> (M + start * N), &N, const_cast<double *> (xpyTV), &inc, &zero, Hxpy, &inc);
+		dgemv_(transn, &N, &length, &one, const_cast<double *> (M + start * N), &N, const_cast<double *> (xpyTV), &inc, &zero, Hxpy, &inc FCONE);
 
 		double scalar = -2.0 / Metric(x, xpy, xpy);
 		Hx->CopyTo(result);
@@ -147,7 +147,7 @@ namespace ROPTLIB{
 		double one = 1, zero = 0;
 		integer inc = 1, N = ell;
 		// Hty <- M(start : start + length - 1, :)^T * yv, details: http://www.netlib.org/lapack/explore-html/dc/da8/dgemv_8f.html
-		dgemv_(transt, &length, &N, &one, const_cast<double *> (M + start), &N, const_cast<double *> (yv), &inc, &zero, Hty, &inc);
+		dgemv_(transt, &length, &N, &one, const_cast<double *> (M + start), &N, const_cast<double *> (yv), &inc, &zero, Hty, &inc FCONE);
 
 		double scalar = -2.0 / Metric(x, xpy, xpy);
 		const double *xpyTV = xpy->ObtainReadData();
