@@ -40,4 +40,4 @@ namespace ROPTLIB{
 				}
 			}
 	}
-}; /*end of ROPTLIB namespace*/
+} /*end of ROPTLIB namespace*/
