@@ -125,8 +125,8 @@ namespace ROPTLIB{
 
 	void RBFGS::PrintInfo(void)
 	{
-		printf("\n\tbetay:%.3e,inpss:%.3e,inpsy:%.3e,IsUpdateHessian:%d,", betay, inpss, inpsy, isupdated);
-		printf("\n");
+		Rprintf("\n\tbetay:%.3e,inpss:%.3e,inpsy:%.3e,IsUpdateHessian:%d,", betay, inpss, inpsy, isupdated);
+		Rprintf("\n");
 	};
 
 	void RBFGS::SetParams(PARAMSMAP params)
@@ -151,4 +151,4 @@ namespace ROPTLIB{
 					}
 		}
 	};
-}; /*end of ROPTLIB namespace*/
+} /*end of ROPTLIB namespace*/
