@@ -128,8 +128,8 @@ namespace ROPTLIB{
 
 	void RBroydenFamily::PrintInfo(void)
 	{
-		printf("\n\tbetay:%.3e,Phic:%.3e,inpss:%.3e,inpsy:%.3e,IsUpdateHessian:%d,", betay, phic, inpss, inpsy, isupdated);
-		printf("\n");
+		Rprintf("\n\tbetay:%.3e,Phic:%.3e,inpss:%.3e,inpsy:%.3e,IsUpdateHessian:%d,", betay, phic, inpss, inpsy, isupdated);
+		Rprintf("\n");
 	};
 
 	void RBroydenFamily::SetParams(PARAMSMAP params)
@@ -154,4 +154,4 @@ namespace ROPTLIB{
 					}
 		}
 	};
-}; /*end of ROPTLIB namespace*/
+} /*end of ROPTLIB namespace*/
